@@ -332,6 +332,11 @@
 	"    # after the whole file has been searched.\n"
 	"\n"
 	"    set sz  [tell $fd]\n"
+	"    if {[info exists ::zip::max_header_seek]} {\n"
+	"        if {$::zip::max_header_seek < $sz} {\n"
+	"            set sz $::zip::max_header_seek\n"
+	"        }\n"
+	"    } \n"
 	"    set len 512\n"
 	"    set at  512\n"
 	"    while {1} {\n"
@@ -353,7 +358,12 @@
 	"    }\n"
 	"\n"
 	"    set hdr [string range $hdr [expr $pos + 4] [expr $pos + 21]]\n"
-	"    set pos [expr [tell $fd] + $pos - 512]\n"
+	"\n"
+	"    set seekstart [expr {[tell $fd] - 512}]\n"
+	"    if {$seekstart < 0} {\n"
+	"        set seekstart 0\n"
+	"    }\n"
+	"    set pos [expr {$seekstart + $pos}]\n"
 	"\n"
 	"    binary scan $hdr ssssiis \\\n"
 	"	cb(ndisk) cb(cdisk) \\\n"
@@ -368,7 +378,11 @@
 	"\n"
 	"    # Compute base for situations where ZIP file\n"
 	"    # has been appended to another media (e.g. EXE)\n"
-	"    set cb(base)	[expr { $pos - $cb(csize) - $cb(coff) }]\n"
+	"    set base            [expr { $pos - $cb(csize) - $cb(coff) }]\n"
+	"    if {$base < 0} {\n"
+	"        set base 0\n"
+	"    }\n"
+	"    set cb(base)	$base\n"
 	"}\n"
 	"\n"
 	"proc zip::TOC {fd arr} {\n"
