@@ -11,9 +11,10 @@ if [ -z "${TCLVERS}" ]; then
 	exit 1
 fi
 
-TLSVERS="1.6"
+TLSVERS="1.6.7"
 SRC="src/tls-${TLSVERS}.tar.gz"
 SRCURL="http://sourceforge.net/projects/tls/files/tls/${TLSVERS}/tls${TLSVERS}-src.tar.gz"
+SRCHASH='-'
 BUILDDIR="$(pwd)/build/tls${TLSVERS}"
 OUTDIR="$(pwd)/out"
 INSTDIR="$(pwd)/inst"
@@ -40,9 +41,7 @@ if [ ! -f "${SRC}" ]; then
 	mkdir 'src' >/dev/null 2>/dev/null
 
 	if [ ! -d 'buildsrc' ]; then
-		rm -f "${SRC}.tmp"
-		wget -O "${SRC}.tmp" "${SRCURL}" || exit 1
-		mv "${SRC}.tmp" "${SRC}"
+		download "${SRCURL}" "${SRC}" "${SRCHASH}" || exit 1
 	fi
 fi
 
@@ -59,7 +58,17 @@ fi
 	if [ -z "${CPP}" ]; then
 		CPP="${CC} -E"
 	fi
-	SSLDIR="$(echo '#include <openssl/ssl.h>' 2>/dev/null | ${CPP} - | awk '/# 1 "\/.*\/ssl\.h/{ print $3; exit }' | sed 's@^"@@;s@"$@@;s@/include/openssl/ssl\.h$@@')"
+
+	if [ -n "${KC_TLS_SSLDIR}" ]; then
+		SSLDIR="${KC_TLS_SSLDIR}"
+	else
+		SSLDIR="$(echo '#include <openssl/ssl.h>' 2>/dev/null | ${CPP} - | awk '/# 1 "\/.*\/ssl\.h/{ print $3; exit }' | sed 's@^"@@;s@"$@@;s@/include/openssl/ssl\.h$@@')"
+		if [ -z "${SSLDIR}" ]; then
+			echo "Unable to find OpenSSL, aborting." >&2
+
+			exit 1
+		fi
+	fi
 
 	# Apply required patches
 	cd "${BUILDDIR}" || exit 1
@@ -87,7 +96,12 @@ fi
 	CFLAGS="${CFLAGS} -DNO_SSL2=1"
 
 	SAVE_CFLAGS="${CFLAGS}"
+	SAVE_LIBS="${LIBS}"
 	for tryopt in $tryopts __fail__; do
+		CFLAGS="${SAVE_CFLAGS}"
+		LIBS="${SAVE_LIBS}"
+		export CFLAGS LIBS
+
 		# Clean up, if needed
 		make distclean >/dev/null 2>/dev/null
 		rm -rf "${INSTDIR}"
@@ -103,14 +117,16 @@ fi
 			isshared="0"
 		fi
 
+		# If building a shared TLS, add the LINKADD libraries here
+		if [ "${isshared}" = '1' ]; then
+			LIBS="${LIBS} ${KC_TLS_LINKADD}"
+		fi
+
 		# If build a static TLS for KitDLL, ensure that we use PIC
 		# so that it can be linked into the shared object
 		if [ "${isshared}" = "0" -a "${KITTARGET}" = "kitdll" ]; then
-			CFLAGS="${SAVE_CFLAGS} -fPIC"
-		else
-			CFLAGS="${SAVE_CFLAGS}"
+			CFLAGS="${CFLAGS} -fPIC"
 		fi
-		export CFLAGS
 
 		if [ "${isshared}" = '0' ]; then
 			sed 's@USE_TCL_STUBS@XXX_TCL_STUBS@g' configure > configure.new
@@ -131,6 +147,11 @@ fi
 			${MAKE:-make} tcllibdir="${INSTDIR}/lib" AR="${AR:-ar}" RANLIB="${RANLIB:-ranlib}" install || exit 1
 		) || continue
 
+		# Determine SSL library directory
+		SSL_LIB_DIR="$(${MAKE:-make} --print-data-base | awk '/^SSL_LIB_DIR = /{ print }' | sed 's@^SSL_LIB_DIR = *@@')"
+
+		echo "SSL_LIB_DIR = ${SSL_LIB_DIR}"
+
 		break
 	done
 
@@ -143,13 +164,20 @@ package ifneeded tls ${TLSVERS} \
 _EOF_
 	fi
 
-	## XXX: TODO: Determine what we actually need to link against
-	addlibs="-lssl -lcrypto"
-	if [ "${KC_TLS_LINKSSLSTATIC}" = '1' ]; then
-		echo "-Wl,-Bstatic ${addlibs} -Wl,-Bdynamic"
-	else
-		echo "${addlibs}"
-	fi > "${INSTDIR}/lib/tls${TLSVERS}/libtls${TLSVERS}.a.linkadd"
+	# Determine name of static object
+	LINKADDFILE="$(find "${INSTDIR}" -name '*.a' | head -n 1)"
+	if [ -n "${LINKADDFILE}" ]; then
+		LINKADDFILE="${LINKADDFILE}.linkadd"
+
+		## XXX: TODO: Determine what we actually need to link against
+		addlibs="-L${SSL_LIB_DIR:-/lib} -lssl -lcrypto ${KC_TLS_LINKADD}"
+		addlibs_staticOnly=""
+		if [ "${KC_TLS_LINKSSLSTATIC}" = '1' ]; then
+			echo "-Wl,-Bstatic ${addlibs} ${addlibs_staticOnly} -Wl,-Bdynamic"
+		else
+			echo "${addlibs}"
+		fi > "${LINKADDFILE}"
+	fi
 
 	# Install files needed by installation
 	cp -r "${INSTDIR}/lib" "${OUTDIR}" || exit 1
